<p>
    Vous êtes abonné au flux {url}, les articles devraient arriver prochainement.<br>
    Pour les filter dans votre client mail, vous pouvez utiliser le header X-Flumel-Title = "{title}"
</p>

<p>Vous se désabonner il suffit d’envoyer un mail titré "Désabonnement {url}" à l'expéditeur de ce message.</p>